//
//  ViewController.m
//  PrioritiesExample
//
//  Created by Matthew Houlden on 26/01/2017.
//  Copyright © 2017 Airsource. All rights reserved.
//

#import "ViewController.h"

const CGFloat kMinContainerViewWidth = 320;

@interface ViewController ()

@property (strong, nonatomic) IBOutlet UISegmentedControl *segmentedControl;
@property (strong, nonatomic) IBOutlet UIView *containerView1;
@property (strong, nonatomic) IBOutlet UIView *containerView2;
@property (strong, nonatomic) IBOutlet UIView *containerView3;
@property (strong, nonatomic) IBOutlet UIView *containerView4;
@property (strong, nonatomic) IBOutlet UIView *containerView5;
@property (strong, nonatomic) IBOutlet NSLayoutConstraint *containerViewLeadingConstraint;
@property (strong, nonatomic) IBOutlet UISlider *slider;

@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    for (UIView *view in @[self.containerView1, self.containerView2, self.containerView3, self.containerView4, self.containerView5])
    {
        view.layer.borderColor = [UIColor blackColor].CGColor;
        view.layer.borderWidth = 1.f;
    }
    
    self.segmentedControl.selectedSegmentIndex = 0;
    [self updateViews];
    
    self.slider.value = 1.f;
    [self updateConstraints];
}

- (IBAction)segmentedControlDidChange:(id)sender
{
    [self updateViews];
}

- (void)updateViews
{
    NSUInteger selectedIndex = self.segmentedControl.selectedSegmentIndex;
    self.containerView1.hidden = (selectedIndex != 0);
    self.containerView2.hidden = (selectedIndex != 1);
    self.containerView3.hidden = (selectedIndex != 2);
    self.containerView4.hidden = (selectedIndex != 3);
    self.containerView5.hidden = (selectedIndex != 4);
}

- (IBAction)sliderDidChange:(id)sender
{
    [self updateConstraints];
}

- (void)updateConstraints
{
    CGFloat maxLeadingConstraint = (self.view.frame.size.width - kMinContainerViewWidth) / 2.f;
    CGFloat minLeadingConstraint = 1.f;
    CGFloat value = self.slider.value;
    CGFloat leadingConstraint = minLeadingConstraint + (maxLeadingConstraint - minLeadingConstraint) * (1.f - value);
    self.containerViewLeadingConstraint.constant = leadingConstraint;
}

@end
